==> ejc-jltest-api-3.0.0-20240313.065036-70-sources.jar: com/ejianc/business/jltest/orgtest/vo/PlanbDetailVO.java <==
package com.ejianc.business.jltest.orgtest.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 安措费使用计划B明细
 * 
 * @author generator
 * 
 */
public class PlanbDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long planbId; // 主表主键ID
    private String detailPlanbName; // 安全费用项目名称
    private BigDecimal detailPlanbMny; // 拟投入金额（万元）
    private String detailMemo; // 备注
    private String orgTest; // 集团类型（1-集团 2-组织 3-分公司）
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private String orgCode; // 组织code
    private BigDecimal detailPlanbMaxMny; // 最大拟投入金额（万元）
    private String errorMsg; // 导入错误信息

    public String getOrgTest() {
        return orgTest;
    }

    public void setOrgTest(String orgTest) {
        this.orgTest = orgTest;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }



    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public BigDecimal getDetailPlanbMaxMny() {
        return detailPlanbMaxMny;
    }

    public void setDetailPlanbMaxMny(BigDecimal detailPlanbMaxMny) {
        this.detailPlanbMaxMny = detailPlanbMaxMny;
    }

    public Long getPlanbId() {
        return planbId;
    }

    public void setPlanbId(Long planbId) {
        this.planbId = planbId;
    }
    public String getDetailPlanbName() {
        return detailPlanbName;
    }

    public void setDetailPlanbName(String detailPlanbName) {
        this.detailPlanbName = detailPlanbName;
    }
    public BigDecimal getDetailPlanbMny() {
        return detailPlanbMny;
    }

    public void setDetailPlanbMny(BigDecimal detailPlanbMny) {
        this.detailPlanbMny = detailPlanbMny;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }

}

==> ejc-jltest-api-3.0.0-20240402.054519-155-sources.jar: com/ejianc/business/jltest/orgtest/vo/PlanbDetailVO.java <==
package com.ejianc.business.jltest.orgtest.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 安措费使用计划B明细
 * 
 * @author generator
 * 
 */
public class PlanbDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long planbId; // 主表主键ID
    private String detailPlanbName; // 安全费用项目名称
    private BigDecimal detailPlanbMny; // 拟投入金额（万元）
    private String detailMemo; // 备注
    private String orgTest; // 集团类型（1-集团 2-组织 3-分公司）
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private String orgCode; // 组织code
    private BigDecimal detailPlanbMaxMny; // 最大拟投入金额（万元）
    private String errorMsg; // 导入错误信息
    private Integer orgType; // 类型

    public Integer getOrgType() {
        return orgType;
    }

    public void setOrgType(Integer orgType) {
        this.orgType = orgType;
    }

    public String getOrgTest() {
        return orgTest;
    }

    public void setOrgTest(String orgTest) {
        this.orgTest = orgTest;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }



    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public BigDecimal getDetailPlanbMaxMny() {
        return detailPlanbMaxMny;
    }

    public void setDetailPlanbMaxMny(BigDecimal detailPlanbMaxMny) {
        this.detailPlanbMaxMny = detailPlanbMaxMny;
    }

    public Long getPlanbId() {
        return planbId;
    }

    public void setPlanbId(Long planbId) {
        this.planbId = planbId;
    }
    public String getDetailPlanbName() {
        return detailPlanbName;
    }

    public void setDetailPlanbName(String detailPlanbName) {
        this.detailPlanbName = detailPlanbName;
    }
    public BigDecimal getDetailPlanbMny() {
        return detailPlanbMny;
    }

    public void setDetailPlanbMny(BigDecimal detailPlanbMny) {
        this.detailPlanbMny = detailPlanbMny;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }

}
